//importing libraries
import { csv } from 'd3';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

// Defining colors for the Pie Chart
const sectionColors = [
  		'darkgreen', 'Purple', 'red', 'yellow', 'blue', 'crimson', 'khaki', 'magenta', 'aqua'
		  ];

// URL of dataset
const csvUrl = 'https://gist.githubusercontent.com/nagasai-gummadi/d50211b90f2b6dea2f25569b15df26ed/raw/b215c04f2d5ece7140c9ad290b3b8febfb538a9e/pie.csv';

// Creating a function for fetching the data
const fetchData = async () => {
  const data = await csv(csvUrl);
  return data;
};

//Adjusting height and width
const svg = select("svg");
const width = + svg.attr('width');
const height = + svg.attr('height');

// Text formatting on the pie chart
const xAxisTickFormat = number =>
  	format('.7')(number);

// rendering pie chart 
const render = (data, total) => {
  const pieData = pie().value(d=>d.TotalCases)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range(sectionColors);
  
  // Arcs 
  const arcGenerator = d3.arc()
  .innerRadius(0)
  .outerRadius(250);

  //arc angles and radius
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(180)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  
  //filling the colors
  sections.enter()
    .append("path")
    .attr("d", segments)
  	.attr("fill", d => colors(d.data.TotalCases));
  
  // Applying colors for each arc
  sections
    .enter()
    .append('text')
    .text(d => xAxisTickFormat((d.data.TotalCases)))
    .attr("transform", function(d) { return "translate(" + arcGenerator.centroid(d) + ")";  })
    .style("text-anchor", "middle")
  	.style('fill', 'black')
    .style("font-size", 12);
  
  // Legend for the data
  
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*25})`;
    });
  
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.TotalCases));
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.Country);
  legend.append("text")
  	.attr("x", 200)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.TotalCases/1))); 
} 

// Main function for the code
const run = async () => {
  let data = await fetchData()
  let total = 0
  data.forEach(d=>{
    d.TotalCases = +d.TotalCases;
    total += d.TotalCases
  });
	render(data,total);
};
run();